Fact.BootstrapFile.Context (Fact v0.3.1)

The context for a bootstrapping the Fact database.

The Fact.BootstrapFile.Context holds all the configuration, for reading, and writing the bootstrap file, which contains just enough configuration information to read the Fact.Context when bootstrapping a database.

Summary

Types

t()

(since 0.2.0)
@type t() :: %{
  decoder: Fact.Seam.Instance.t(),
  encoder: Fact.Seam.Instance.t(),
  name: Fact.Seam.Instance.t(),
  reader: Fact.Seam.Instance.t(),
  writer: Fact.Seam.Instance.t()
}