Fact.BootstrapFile.Decoder (Fact v0.3.1)

Adapter for decoding the contents of the bootstrap file.

Summary

Functions

Helper function to decode the bootstrap file using the configured Fact.Seam.Decoder.

Functions

decode(context, value)

(since 0.2.0)
@spec decode(Fact.BootstrapFile.Context.t(), binary()) ::
  {:ok, term()} | {:error, term()}

Helper function to decode the bootstrap file using the configured Fact.Seam.Decoder.

from_config(config)

(since 0.2.0)

init(options \\ %{})

(since 0.2.0)

init(impl_id, options)

(since 0.2.0)