Fact.BootstrapFile.Encoder (Fact v0.3.1)

Adapter for encoding the contents of the bootstrap file.

Summary

Functions

Helper function to encode the bootstrap file using the configured Fact.Seam.Encoder.

Functions

encode(context, value)

(since 0.2.0)
@spec encode(Fact.BootstrapFile.Context.t(), term()) ::
  {:ok, iodata()} | {:error, term()}

Helper function to encode the bootstrap file using the configured Fact.Seam.Encoder.

from_config(config)

(since 0.2.0)

init(options \\ %{})

(since 0.2.0)

init(impl_id, options)

(since 0.2.0)