Fact.BootstrapFile.Name (Fact v0.3.1)
View SourceAdapter for naming the bootstrap file.
Summary
Functions
Helper function to get the file name using the configured Fact.Seam.FileName.
Functions
@spec get(Fact.BootstrapFile.Context.t()) :: String.t()
Helper function to get the file name using the configured Fact.Seam.FileName.