Fact.BootstrapFile.Reader (Fact v0.3.1)
View SourceAdapter for reading the bootstrap file.
Summary
Functions
Helper function to read the bootstrap file using the configured Fact.Seam.FileReader.
Adapter for reading the bootstrap file.
Helper function to read the bootstrap file using the configured Fact.Seam.FileReader.