Fact.BootstrapFile.Writer (Fact v0.3.1)
View SourceAdapter for writing the bootstrap file.
Summary
Functions
Helper function to write the bootstrap file using the configured Fact.Seam.FileWriter.
Adapter for writing the bootstrap file.
Helper function to write the bootstrap file using the configured Fact.Seam.FileWriter.