Fact.BuildInfo (Fact v0.3.1)

Compile-time build metadata for the project.

Fun Fact

I went live with my 0.1.0 release, never testing creation of a database outside of this project. I made a piss poor assumption about Mix.Project, and the result was databases could not be created via mix fact.create. This module is the remedy. It stores some of the key metadata fields defined in mix.exs at compile time so they can be used in downstream projects without bombing.

Live and learn! 🍺

Summary

Functions

The release code name.

The canonical url to the documentation.

The library name.

The library version.

Functions

codename()

@spec codename() :: binary()

The release code name.

docs_url()

@spec docs_url() :: binary()

The canonical url to the documentation.

name()

@spec name() :: binary()

The library name.

version()

@spec version() :: binary()

The library version.