Fact.CatchUpSubscription.All (Fact v0.3.1)

Catch-up subscription for the all stream.

This subscription replays every event in the database from the selected starting position up to the current position, delivers them to the subscriber, and then transitions into live mode to stream new events as they are appended.

Summary

Functions

Returns a specification to start this module under a supervisor.

Functions

child_spec(init_arg)

Returns a specification to start this module under a supervisor.

See Supervisor.

start_link(options)