Fact.CatchUpSubscription.Index (Fact v0.3.1)

Catch-up subscription for a single index value.

This subscription replays and streams events that appear in the given index, starting from the configured position and continuing in live mode once caught up.

Summary

Functions

Returns a specification to start this module under a supervisor.

Functions

child_spec(init_arg)

Returns a specification to start this module under a supervisor.

See Supervisor.

start_link(options)