Fact.CatchUpSubscription.Query (Fact v0.3.1)

Catch-up subscription for event queries.

This subscription replays and streams events that match a set of Fact.QueryItem.t/0 query items. It coordinates with the underlying indexers to ensure only relevant events are delivered.

Summary

Functions

Returns a specification to start this module under a supervisor.

Functions

child_spec(init_arg)

Returns a specification to start this module under a supervisor.

See Supervisor.

start_link(options)