Fact.CatchUpSubscription.Stream (Fact v0.3.1)

Catch-up subscription for a single event stream.

This subscription replays and streams events from a specific event stream in the database, starting from the configured position and delivering them to the subscriber. Once caught up, it continues streaming new events as they are appended to the stream.

Summary

Functions

Returns a specification to start this module under a supervisor.

Functions

child_spec(init_arg)

Returns a specification to start this module under a supervisor.

See Supervisor.

start_link(options)