Fact.IndexCheckpointFile (Fact v0.3.1)
View SourceDomain-specific module that encapsulates configurable adapters for working with index checkpoint files.
This provides helper functions to make it easier than directly working
with the adapters and Fact.Context modules.