Fact.IndexCheckpointFile.Decoder (Fact v0.3.1)

Adapter for decoding the contents of index checkpoint files.

There is currently only a single allowed implementation, see Fact.Seam.Decoder.Integer.V1.

Summary

Functions

decode(context, value, opts \\ [])

from_config(config)

init(options \\ %{})

init(impl_id, options)