Fact.IndexCheckpointFile.Encoder (Fact v0.3.1)
View SourceAdapter for encoding the contents of index checkpoint files.
There is currently only a single allowed implementation, see Fact.Seam.Encoder.Integer.V1.
Adapter for encoding the contents of index checkpoint files.
There is currently only a single allowed implementation, see Fact.Seam.Encoder.Integer.V1.