Fact.IndexCheckpointFile.Name (Fact v0.3.1)
View SourceAdapter for naming the index checkpoint files within the file system.
There is currently only a single allowed implementation, see Fact.Seam.Encoder.Fixed.V1.
Adapter for naming the index checkpoint files within the file system.
There is currently only a single allowed implementation, see Fact.Seam.Encoder.Fixed.V1.