Fact.IndexCheckpointFile.Writer (Fact v0.3.1)

Adapter for writing the contents of index checkpoint files to the file system.

There is currently only a single allowed implementation, see Fact.Seam.FileWriter.Standard.V1.

Index checkpoint files are opened in write mode, overwriting any existing contents.

Summary

Functions

from_config(config)

init(options \\ %{})

init(impl_id, options)

write(context, path, value, options \\ [])