Fact.IndexFile (Fact v0.3.1)
View SourceDomain-specific module that encapsulates configurable adapters for working with index files.
This provides helper functions to make it easier than working with
adapters and Fact.Context module.
Domain-specific module that encapsulates configurable adapters for working with index files.
This provides helper functions to make it easier than working with
adapters and Fact.Context module.