Fact.IndexFile.Decoder (Fact v0.3.1)
View SourceAdapter for decoding the contents of index files.
There is currently only a single allowed implementation, see Fact.Seam.Decoder.Raw.V1.
Adapter for decoding the contents of index files.
There is currently only a single allowed implementation, see Fact.Seam.Decoder.Raw.V1.