Fact.IndexFile.Name (Fact v0.3.1)
View SourceAdapter for naming the index files within the file system.
This defaults to using the Fact.Seam.FileName.Raw.V1 implementation,
but can be configured to use Fact.Seam.FileName.Hash.V1.
Adapter for naming the index files within the file system.
This defaults to using the Fact.Seam.FileName.Raw.V1 implementation,
but can be configured to use Fact.Seam.FileName.Hash.V1.