Fact.IndexFile.Writer (Fact v0.3.1)

Adapter for writing the contents of index files to the file system.

There is currently only a single allowed implementation, see Fact.Seam.FileWriter.Standard.V1.

Index files are opened in append mode, writing new data to the end of the file.

Summary

Functions

from_config(config)

init(options \\ %{})

init(impl_id, options)

write(context, path, value, options \\ [])