Fact.LedgerFile.Encoder (Fact v0.3.1)
View SourceAdapter for encoding the contents of ledger file.
There is currently only a single allowed implementation, see Fact.Seam.Encoder.Delimited.V1.
Adapter for encoding the contents of ledger file.
There is currently only a single allowed implementation, see Fact.Seam.Encoder.Delimited.V1.