Fact.LedgerFile.Reader (Fact v0.3.1)
View SourceAdapter for reading the contents of the ledger file.
There is currently only a single allowed implementation, see Fact.Seam.FileReader.FixedLength.V1.
Adapter for reading the contents of the ledger file.
There is currently only a single allowed implementation, see Fact.Seam.FileReader.FixedLength.V1.