Fact.LockFile.Encoder (Fact v0.3.1)
View SourceAdapter for encoding the contents of lock file.
There is currently only a single allowed implementation, see Fact.Seam.Encoder.Json.V1.
Adapter for encoding the contents of lock file.
There is currently only a single allowed implementation, see Fact.Seam.Encoder.Json.V1.