Fact.LockFile.Name (Fact v0.3.1)

Adapter for naming the lock file within the file system.

There is currently only a single allowed implementation, see Fact.Seam.Encoder.Fixed.V1.

Summary

Functions

from_config(config)

get(context)

get(context, value, options)

init(options \\ %{})

init(impl_id, options)