Fact.LockFile.Writer (Fact v0.3.1)

Adapter for writing the contents of the lock file to the file system.

There is currently only a single allowed implementation, see Fact.Seam.FileWriter.Standard.V1.

The lock file is opened in write mode, overwriting any existing contents. Although the lock file is normally deleted when the lock is released, certain failure scenarios may leave a stale lock file behind.

Summary

Functions

from_config(config)

init(options \\ %{})

init(impl_id, options)

write(context, path, value, options \\ [])