Fact.RecordFile.Writer (Fact v0.3.1)

Adapter for writing the contents of the lock file to the file system.

There is currently only a single allowed implementation, see Fact.Seam.FileWriter.Standard.V1.

Event records are opened in exclusive write mode, written using raw file descriptors, and explicitly synchronized to disk. After the write completes, the file is marked read-only to prevent further modification.

Summary

Functions

from_config(config)

init(options \\ %{})

init(impl_id, options)

write(context, path, value, options \\ [])