Fact.Seam.Decoder.Adapter (Fact v0.3.1)
View SourceMeta module providing an adapter for dispatching to decoder implementations.
Wraps calls to the underlying Fact.Seam.Decoder implementations and handles context injection.
Meta module providing an adapter for dispatching to decoder implementations.
Wraps calls to the underlying Fact.Seam.Decoder implementations and handles context injection.