Fact.Seam.Decoder.Delimited.V1 (Fact v0.3.1)
View SourceA decoder for delimited content.
Splits a binary string into a list of values based on a configurable delimiter.
Returns {:error, {:decode, value}} if the input is not a binary.
A decoder for delimited content.
Splits a binary string into a list of values based on a configurable delimiter.
Returns {:error, {:decode, value}} if the input is not a binary.