Fact.Seam.Decoder.Integer.V1 (Fact v0.3.1)
View SourceA decoder for integers.
Converts a binary string representation of an integer into an actual integer.
Returns {:error, {:decode, value}} if the input cannot be converted.
A decoder for integers.
Converts a binary string representation of an integer into an actual integer.
Returns {:error, {:decode, value}} if the input cannot be converted.