Fact.Seam.Decoder.Raw.V1 (Fact v0.3.1)

A raw decoder implementation that returns the binary value as-is.

If the input is not binary, returns an error tuple.

Summary

Functions

validate_options(options, specs)