Fact.Seam.Encoder.Adapter (Fact v0.3.1)

Meta module that provides an adapter for calling Fact.Seam.Encoder implementations.

This adapter handles resolution of the encoder instance from a context and forwards the encode/3 call to the underlying implementation.