Fact.Seam.Encoder.Raw.V1 (Fact v0.3.1)
View SourceStandard raw encoder implementation that passes binary content through unchanged.
This encoder only accepts binary data. Non-binary input returns an :encode_error.
Standard raw encoder implementation that passes binary content through unchanged.
This encoder only accepts binary data. Non-binary input returns an :encode_error.