Fact.Seam.EventSchema.Adapter (Fact v0.3.1)

Meta module providing an adapter for Fact.Seam.EventSchema.

This module injects functions for dispatching calls to a configured Fact.Seam.EventSchema implementation, handling database context lookup, and passing options to the selected instance.