Fact.Seam.FileName.Fixed.V1 (Fact v0.3.1)

A file name implementation that returns a fixed, preconfigured name.

This Fact.Seam.FileName implementation ignores the value input and always returns the fixed :name specified in its configuration.

Summary

Functions

validate_options(options, specs)