Fact.Seam.FileReader.Full.V1 (Fact v0.3.1)

A Fact.Seam.FileReader implementation that reads the entire file content at once.

The file is read as a single binary, then wrapped in a Stream to provide a consistent streaming interface for downstream consumers.

Summary

Functions

validate_options(options, specs)