Fact.Seam.FileWriter.Registry (Fact v0.3.1)
View SourceRegistry of all configured Fact.Seam.FileWriter implementations.
Provides a lookup for allowed implementations, their versions, and the latest default implementation.
Registry of all configured Fact.Seam.FileWriter implementations.
Provides a lookup for allowed implementations, their versions, and the latest default implementation.