Fact.Storage (Fact v0.3.1)
View SourceAdapter for working with configurable storage implementations.
There is currently only a single implementation, see Fact.Seam.Storage.Standard.V1.
Adapter for working with configurable storage implementations.
There is currently only a single implementation, see Fact.Seam.Storage.Standard.V1.