mix fact.merkle.root (Fact v0.3.1)

Prints the current MMR peak hashes for a database.

The peak hashes together form the root commitment to the entire event history. These can be shared with auditors for independent verification.

Usage

mix fact.merkle.root -p <path>

Options

  • -p, --path - (required) Path to the database directory.