Fact.BootstrapFile.Decoder (Fact v0.3.1)
View SourceAdapter for decoding the contents of the bootstrap file.
Summary
Functions
Helper function to decode the bootstrap file using the configured Fact.Seam.Decoder.
Functions
@spec decode(Fact.BootstrapFile.Context.t(), binary()) :: {:ok, term()} | {:error, term()}
Helper function to decode the bootstrap file using the configured Fact.Seam.Decoder.