Fact.BootstrapFile.Encoder (Fact v0.3.1)
View SourceAdapter for encoding the contents of the bootstrap file.
Summary
Functions
Helper function to encode the bootstrap file using the configured Fact.Seam.Encoder.
Functions
@spec encode(Fact.BootstrapFile.Context.t(), term()) :: {:ok, iodata()} | {:error, term()}
Helper function to encode the bootstrap file using the configured Fact.Seam.Encoder.