Fact.IndexCheckpointFile.Decoder (Fact v0.3.1)
View SourceAdapter for decoding the contents of index checkpoint files.
There is currently only a single allowed implementation, see Fact.Seam.Decoder.Integer.V1.
Adapter for decoding the contents of index checkpoint files.
There is currently only a single allowed implementation, see Fact.Seam.Decoder.Integer.V1.