Fact.IndexFile.Writer (Fact v0.3.1)
View SourceAdapter for writing the contents of index files to the file system.
There is currently only a single allowed implementation, see Fact.Seam.FileWriter.Standard.V1.
Index files are opened in append mode, writing new data to the end of the file.