Fact.LedgerFile.Writer (Fact v0.3.1)
View SourceAdapter for writing the contents of ledger file to the file system.
There is currently only a single allowed implementation, see Fact.Seam.FileWriter.Standard.V1.
The ledger file opened for append-only writes using raw file descriptors, and each write is synchronously flushed to disk to ensure durability.