Fact.RecordFile.Reader (Fact v0.3.1)
View SourceAdapter for reading the contents of the event record files.
There is currently only a single allowed implementation, see Fact.Seam.FileReader.Full.V1.
Adapter for reading the contents of the event record files.
There is currently only a single allowed implementation, see Fact.Seam.FileReader.Full.V1.