Fact.Seam.FileName.Raw.V1 (Fact v0.3.1)
View SourceA raw file name implementation that returns the input value unchanged.
This Fact.Seam.FileName implementation simply passes through the given value as the file name.
A raw file name implementation that returns the input value unchanged.
This Fact.Seam.FileName implementation simply passes through the given value as the file name.