Fact.Seam.Storage.Registry (Fact v0.3.1)
View SourceRegistry for Fact.Seam.Storage implementations.
This module provides:
- A list of all known storage implementations.
- Resolution of a specific implementation by
{family, version}. - Access to the latest version of a storage implementation for a given family.
Usage
Use this registry to:
- Retrieve all storage implementations via
all/0. - Resolve a specific implementation via
resolve/1orresolve/2. - Get the latest implementation or version for a given storage family.
This registry currently contains the following implementation(s):
* `Fact.Seam.Storage.Standard.V1`