Fact.Seam.Storage.Standard.V1 (Fact v0.3.1)
View SourceStandard V1 implementation of the Fact.Seam.Storage seam.
This module provides file-system–based storage paths for a database context. It defines where event records, indices, ledgers, and locks are stored on disk.
Options:
:path– the root directory for the database storage. All sub-paths are derived from this.
Summary
Functions
Gets the path to the base directory for all indexes.
Creates the directory structure used for events and indexes.
Gets the path to the directory containing the ledger.
Gets the path to the directory containing the database lock file.
Gets the path to the Merkle Mountain Range directory.
Gets the configured root path for the database.
Gets the path to base directory for records, or the path to a specific record.
Gets the path to the directory containing the write ahead log segment files.
Types
@type t() :: %Fact.Seam.Storage.Standard.V1{path: Path.t()}
The configuration options for the Standard v1 storage seam impl.
Functions
Gets the path to the base directory for all indexes.
Creates the directory structure used for events and indexes.
Gets the path to the directory containing the ledger.
Gets the path to the directory containing the database lock file.
Gets the path to the Merkle Mountain Range directory.
Gets the configured root path for the database.
@spec records_path(t(), nil | Fact.record_id(), keyword()) :: Path.t()
Gets the path to base directory for records, or the path to a specific record.
Gets the path to the directory containing the write ahead log segment files.