mix fact.backup (Fact v0.3.1)
View SourceBacks up the contents of a Fact database.
Usage
mix fact.backup --path path/to/db --output backup.zip
mix fact.backup --path path/to/db --output some_dir
mix fact.backup --path path/to/db --output some_dir --include-indicesIf the output path is a directory, the ZIP file name is derived from the last segment of the input path plus a timestamp.